@@ -12,7 +12,7 @@ use Encode;
 use WWW::PGXN;
 use List::MoreUtils qw(any);
 use namespace::autoclean;
-our $VERSION = v0.10.3;
+our $VERSION = v0.20.0;
 
 Template::Declare->init( dispatch_to => ['PGXN::Site::Templates'] );
 
@@ -353,7 +353,7 @@ PGXN::Site::Controller - The PGXN::Site request controller
   use PGXN::Site::Controller;
   use Router::Resource;
 
-  my $controller = PGXN::Site::Controller->new(url => 'http://api.pgxn.org');
+  my $controller = PGXN::Site::Controller->new(url => 'https://api.pgxn.org');
   my $router = router {
       resource '/' => sub {
           GET { $controller->home(@_) };
@@ -558,10 +558,10 @@ David E. Wheeler <david.wheeler@pgexperts.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2010-2013 David E. Wheeler.
+Copyright (c) 2010-2021 David E. Wheeler.
 
 This module is free software; you can redistribute it and/or modify it under
-the L<PostgreSQL License|http://www.opensource.org/licenses/postgresql>.
+the L<PostgreSQL License|https://www.opensource.org/licenses/postgresql>.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose, without fee, and without a written agreement is
